.. -*- coding: utf-8 -*-

Chaque utilisateur authentifié peut définir ses propres signets dans
l'application. Ils fonctionnent comme des signets dans un navigateur, mais sont
restreints aux liens internes au site et sont conservés dans la base de données,
ce qui vous permet de les retrouver quelque soit le navigateur que vous utilisez
pour vous connecter au site. Ils sont disponibles dans la boîte des signets, à
gauche de l'écran.

Pour ajouter un signet sur la page que vous être en train de visualiser, vous
devez cliquer sur le menu déroulant `gérer des signets`; puis sur `poser un
signet ici` de la boîte pour faire apparaître le champ d'ajout. Il est alors
demandé de lui donner un titre. Une fois créé, le signet apparaît dans la boîte
des signets.

Le signe `[-]` en face du signet permet sa suppression immédiate.

Le lien `récupérer un signet` du menu déroulant permet de voir une liste des
signets déja définis par les autres utilisateurs de l'application. Si l'un de
ces signets vous intéresse, vous pouvez l'ajouter à vos signet en cliquant sur
le signe `[+]` à gauche de celui-ci.

Le lien `éditer les signets` du menu déroulant permet de modifier vos signets
(par exemple changer leur titre) et le chemin relatif du signet. Si vous
utilisez des signets partagés (que vous avez récupéré d'un autre utilisateur),
ceux-ci n'apparaîtront pas dans le formulaire de modification à moins que vous
ayez le droit de les modifier.


.. _`préférences utilisateurs`: ../myprefs
